==> beamlit-0.0.56rc104.tar.gz: beamlit-0.0.56rc104/docs/beamlit/api/models/delete_model.md <==
Module beamlit.api.models.delete_model
======================================

Functions
---------

`asyncio(model_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.models.model.Model | None`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Model

`asyncio_detailed(model_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.types.Response[beamlit.models.model.Model]`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Model]

`sync(model_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.models.model.Model | None`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Model

`sync_detailed(model_name: str, *, client: beamlit.client.AuthenticatedClient, environment: str) ‑> beamlit.types.Response[beamlit.models.model.Model]`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
        environment (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Model]

==> beamlit-0.0.62.tar.gz: beamlit-0.0.62/docs/beamlit/api/models/delete_model.md <==
Module beamlit.api.models.delete_model
======================================

Functions
---------

`asyncio(model_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.models.model.Model | None`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Model

`asyncio_detailed(model_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.types.Response[beamlit.models.model.Model]`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Model]

`sync(model_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.models.model.Model | None`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Model

`sync_detailed(model_name: str, *, client: beamlit.client.AuthenticatedClient) ‑> beamlit.types.Response[beamlit.models.model.Model]`
:   Delete model
    
     Deletes a model by name.
    
    Args:
        model_name (str):
    
    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.
    
    Returns:
        Response[Model]
